#
# File: OP/Recur/Break.pm
#
# Copyright (c) 2009 TiVo Inc.
#
# All rights reserved. This program and the accompanying materials
# are made available under the terms of the Common Public License v1.0
# which accompanies this distribution, and is available at
# http://opensource.org/licenses/cpl1.0.txt
#
package OP::Recur::Break;

use strict;
use warnings;

use base qw/ Error /;

1;
__END__
=pod

=head1 NAME

OP::Recur::Break - Break statement for Recur loops

=head1 SYNOPSIS

This module should not be used directly. See L<OP::Recur>.

=head1 SEE ALSO

This file is part of L<OP>.

=cut 
